<?php
/**
 * Turbotext API Class
 *
 * @package TurbotextAI
 * @since 1.0.0
 */

if (!defined('ABSPATH')) {
    exit;
}

/**
 * Class TurbotextApi
 */
class TurbotextApi {
    /** @var string */
    private $server = 'https://www.turbotext.ru/api_ai';

    /** @var string */
    private $token;

    /** @var array|null */
    private $queue = null;

    /** @var array|null */
    private $result = null;

    /** @var int */
    private $counter = 0;

    /**
     * TurbotextApi constructor.
     *
     * @param string $token API token
     */
    public function __construct($token) {
        $this->token = $token;
    }

    /**
     * Generate content
     *
     * @param string $url API endpoint
     * @param array  $data Request data
     * @return array|WP_Error
     */
    public function generate($url, $data = array()) {
        try {
            $data['do'] = 'create_queue';
            $result = $this->send_request($url, $data);

            if (is_wp_error($result)) {
                return $result;
            }

            $this->queue = json_decode($result, true);
            
            if (!empty($this->queue['success'])) {
                if (!empty($this->queue['queueid'])) {
                    return $this->get_result($url, array(
                        'do' => 'get_result',
                        'id' => $this->queue['queueid']
                    ));
                }
            }

            return new WP_Error(
                'turbotext_api_error',
                !empty($this->queue['error']) ? $this->queue['error'] : __('Unknown API error', 'turbotext-ai')
            );

        } catch (Exception $e) {
            return new WP_Error('turbotext_api_exception', $e->getMessage());
        }
    }

    /**
     * Get result from API
     *
     * @param string $url API endpoint
     * @param array  $data Request data
     * @return array|WP_Error
     */
    private function get_result($url, $data) {
        if ($this->counter > 10) {
            return new WP_Error(
                'turbotext_api_timeout',
                __('Maximum retry attempts exceeded', 'turbotext-ai')
            );
        }

        $result = $this->send_request($url, $data);
        
        if (is_wp_error($result)) {
            return $result;
        }

        $this->result = json_decode($result, true);

        if (!empty($this->result['action']) && $this->result['action'] === 'reconnect') {
            sleep(3);
            $this->counter++;
            return $this->get_result($url, $data);
        }

        return $this->result;
    }

    /**
     * Send request to API
     *
     * @param string $url API endpoint
     * @param array  $data Request data
     * @return string|WP_Error
     */
    private function send_request($url, $data) {
        $args = array(
            'timeout'     => 120,
            'redirection' => 5,
            'httpversion' => '1.1',
            'blocking'    => true,
            'headers'     => array(
                'Authorization' => 'Bearer ' . $this->token,
                'Content-Type' => 'application/x-www-form-urlencoded',
            ),
            'body'        => $data,
            'cookies'     => array()
        );

        $response = wp_remote_post($this->server . $url, $args);

        if (is_wp_error($response)) {
            return $response;
        }

        $response_code = wp_remote_retrieve_response_code($response);
        if ($response_code !== 200) {
            return new WP_Error(
                'turbotext_api_http_error',
                sprintf(
                    __('HTTP Error: %s', 'turbotext-ai'),
                    $response_code
                )
            );
        }

        $body = wp_remote_retrieve_body($response);
        if (empty($body)) {
            return new WP_Error(
                'turbotext_api_empty_response',
                __('Empty response from API', 'turbotext-ai')
            );
        }

        return $body;
    }

    /**
     * Validate API token
     *
     * @return bool|WP_Error
     */
    public function validate_token() {
        $result = $this->send_request('/validate', array('test' => 1));
        
        if (is_wp_error($result)) {
            return $result;
        }

        $response = json_decode($result, true);
        
        if (!empty($response['success'])) {
            return true;
        }

        return new WP_Error(
            'turbotext_api_invalid_token',
            __('Invalid API token', 'turbotext-ai')
        );
    }
}