<?php
/**
 * Plugin Name: Turbotext AI Integration
 * Plugin URI: https://www.turbotext.ru
 * Description: Integration with Turbotext AI API for content generation
 * Version: 1.0.0
 * Author: Turbotext
 * Author URI: https://www.turbotext.ru/photo_ai/create/generate_rewrite_text_ru
 * License: GPL v2 or later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain: turbotext-ai
 * Requires PHP: 7.2
 */

if (!defined('ABSPATH')) {
    exit;
}

define('TURBOTEXT_AI_VERSION', '1.0.0');
define('TURBOTEXT_AI_PLUGIN_DIR', plugin_dir_path(__FILE__));
define('TURBOTEXT_AI_PLUGIN_URL', plugin_dir_url(__FILE__));

require_once TURBOTEXT_AI_PLUGIN_DIR . 'includes/class-turbotext-api.php';

class TurbotextAIPlugin {
    /** @var TurbotextAIPlugin */
    private static $instance = null;
    
    /** @var TurbotextApi */
    private $api = null;

    /**
     * Get plugin instance
     *
     * @return TurbotextAIPlugin
     */
    public static function get_instance() {
        if (null === self::$instance) {
            self::$instance = new self();
        }
        return self::$instance;
    }

    private function __construct() {
        add_action('admin_menu', array($this, 'add_admin_menu'));
        add_action('admin_init', array($this, 'register_settings'));
        add_action('admin_enqueue_scripts', array($this, 'enqueue_admin_scripts'));
        add_action('wp_ajax_turbotext_generate_content', array($this, 'ajax_generate_content'));
        
        $token = get_option('turbotext_ai_token');
        if ($token) {
            $this->api = new TurbotextApi($token);
        }
    }

    public function add_admin_menu() {
        add_menu_page(
            __('Turbotext AI', 'turbotext-ai'),
            __('Turbotext AI', 'turbotext-ai'),
            'manage_options',
            'turbotext-ai',
            array($this, 'render_admin_page'),
            'dashicons-text'
        );
    }

    public function register_settings() {
        register_setting('turbotext_ai_options', 'turbotext_ai_token');
    }

    public function enqueue_admin_scripts($hook) {
        if ('toplevel_page_turbotext-ai' !== $hook) {
            return;
        }

        wp_enqueue_style(
            'turbotext-ai-admin',
            TURBOTEXT_AI_PLUGIN_URL . 'assets/css/admin.css',
            array(),
            TURBOTEXT_AI_VERSION
        );

        wp_enqueue_script(
            'turbotext-ai-admin',
            TURBOTEXT_AI_PLUGIN_URL . 'assets/js/admin.js',
            array('jquery'),
            TURBOTEXT_AI_VERSION,
            true
        );

        wp_localize_script('turbotext-ai-admin', 'turbotextAI', array(
            'ajaxUrl' => admin_url('admin-ajax.php'),
            'nonce' => wp_create_nonce('turbotext_ai_nonce'),
            'i18n' => array(
                'generating' => __('Generating...', 'turbotext-ai'),
                'generate' => __('Generate', 'turbotext-ai'),
                'emptyPrompt' => __('Please enter a prompt', 'turbotext-ai')
            )
        ));
    }

    public function render_admin_page() {
        include TURBOTEXT_AI_PLUGIN_DIR . 'templates/admin-page.php';
    }

    public function ajax_generate_content() {
        check_ajax_referer('turbotext_ai_nonce', 'nonce');

        if (!current_user_can('manage_options')) {
            wp_send_json_error('Insufficient permissions');
            return;
        }

        $prompt = isset($_POST['prompt']) ? sanitize_textarea_field($_POST['prompt']) : '';
        if (empty($prompt)) {
            wp_send_json_error('Prompt is required');
            return;
        }

        try {
            if (!$this->api) {
                throw new Exception('API not initialized. Please check your API token.');
            }

            $result = $this->api->generate('/generate_rewrite_text_ru', array(
                'content' => $prompt,
                'conversion_level'=>5
            ));

            if (is_wp_error($result)) {
                wp_send_json_error($result->get_error_message());
                return;
            }

            wp_send_json_success($result);
        } catch (Exception $e) {
            wp_send_json_error($e->getMessage());
        }
    }
}

function turbotext_ai_init() {
    TurbotextAIPlugin::get_instance();
}
add_action('plugins_loaded', 'turbotext_ai_init');